Description Usage Arguments Details Value Examples
These functions are used to compute statistics required by the beta chart.
1 |
data |
the observed data values. |
sizes |
sample sizes |
... |
further arguments are ignored. |
Performs the calculation of the standard deviation std.dev that will be used in the construction of the control chart.
The function sd.beta returns std.dev the standard deviation of the statistic charted.
1 2 | data(Montgomery2005)
sd.beta(Montgomery2005$Defective, Montgomery2005$Sample)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.