Description Usage Arguments Details Value Examples
These functions are used to compute statistics required by the beta chart.
1 | stats.beta.p(data,sizes)
|
data |
the observed data values. |
sizes |
sample sizes |
Provides a list containing the center line of the graph center and the data to be used in the construction of the chart statistics.
The function stats.beta.p returns a list with components statistics and center.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.